komodo_ui library

Komodo UI Kit - A comprehensive UI library for DeFi applications Built on top of the Komodo DeFi Framework

Classes

AddressSelectInput
AssetIcon
A widget that displays an icon for a given AssetId.
A widget that displays an AssetIcon with its protocol icon overlaid.
AssetProtocolIcon
A widget that displays a protocol icon with a circular border and shadow, positioned absolutely within its parent widget.
CollapsibleCard
A card component that can expand and collapse to show additional content.
Colors
Color and ColorSwatch constants which represent Material design's color palette.
CryptoAssetCard
A specialized card for displaying crypto asset information with expandable wallet addresses.
DateFormat
DateFormat is for formatting and parsing dates in a locale-sensitive manner.
Debouncer
A utility class that helps to debounce operations by delaying their execution and canceling previous pending operations.
Decimal
A number that can be exactly written with a finite number of digits in the decimal system.
DefaultSelectedItemView
Default view for selected items
DividedButton
A button that displays multiple children separated by dividers.
ErrorDisplay
FeeEstimationDisabled
A widget for displaying the disabled fee estimation state.
FeeInfoDisplay
A widget for displaying FeeInfo details in a consistent format.
FeeInfoInput
A widget for inputting custom fee information.
FeeInfoWithPriority
A widget for displaying fee information with priority selection
Key
A Key is an identifier for Widgets, Elements and SemanticsNodes.
KomodoUi
A high-level widget catalog relevant to building Flutter UI apps which consume Komodo DeFi Framework
MetricSelector
A control widget that displays a selectable metric with a trend.
MetricSelectorController
Controller for managing MetricSelector state
NumberFormat
Provides the ability to format a number in a locale-specific way.
QrCodeReaderOverlay
RecipientAddressField
A form field widget for entering and validating cryptocurrency recipient addresses.
SearchableSelect<T>
Widget that displays a searchable select input
SearchableSelectController<T>
Controller for managing selection state
SearchableSelectorDelegate<T>
SearchableSelectView<T>
Presentation widget for the searchable select
SelectItem
A model class representing a selectable item
SelectItemWidget
A widget that displays a select item with the same parameters as SelectItem
SourceAddressField
StatefulWidget
A widget that has mutable state.
StatelessWidget
A widget that does not require mutable state.
TextStreamBuilder<T>
A widget that displays text from a stream with proper loading and error states.
TextTheme
Material design text theme.
ThemeData
Defines the configuration of the overall visual Theme for a MaterialApp or a widget subtree within the app.
TrendPercentageText
A widget that displays a percentage trend with an indicator icon.
Widget
Describes the configuration for an Element.
WithdrawalFormExample
Example component demonstrating how to handle disabled fee estimation in a withdrawal form.
WithdrawalPrioritySelector
A widget for selecting withdrawal fee priority levels.
WithdrawAmountField
A text input field for entering the withdrawal amount

Enums

AddressStatus
EmptyChildrenBehavior
Controls how the expansion control behaves when there are no children.
ExpansionControlPosition
Controls the position of the expansion control button.

Extensions

EthGasEip1559Formatting on FeeInfoEthGasEip1559
Dedicated formatting extension for only the ethGasEip1559 variant
EthGasFormatting on FeeInfoEthGas
Dedicated formatting extension for only the ethGas variant
FeeInfoFormatting on FeeInfo
MetricDataMethods on MetricData
PubkeyInfoFormatting on PubkeyInfo
Extension methods for formatting PubkeyInfo addresses

Functions

defaultSearchableSelectTheme(Brightness themeMode, ColorScheme colorScheme) InputDecorationTheme
The recommended theme for the SearchableSelect widget.
showAddressSearch(BuildContext context, {required List<PubkeyInfo> addresses, required String assetNameLabel, bool verified(PubkeyInfo)?, void onCopied(PubkeyInfo)?, String searchHint = 'Search addresses', DropdownMenuItem<PubkeyInfo> customItemBuilder(PubkeyInfo address, {bool? isVerified})?}) Future<PubkeyInfo?>
showAddressSelectDropdown({required List<PubkeyInfo> addresses, required String assetName, required BuildContext context, PubkeyInfo? selectedAddress, String hint = 'Select Address', bool verified(PubkeyInfo)?, void onCopied(PubkeyInfo)?, ValueChanged<PubkeyInfo?>? onAddressSelected, InputDecoration? decoration, Widget customSelectedItemBuilder(BuildContext, PubkeyInfo?)?, Widget customItemBuilder(PubkeyInfo, bool)?}) Widget
showCoinSearch(BuildContext context, {required List<AssetId> coins, DropdownMenuItem<AssetId> customCoinItemBuilder(AssetId coinId)?}) Future<AssetId?>
showDropdownSearch<T>(BuildContext context, List<DropdownMenuItem<T>> items, {String searchHint = 'Search', double? minWidth}) Future<T?>
showSearchableSelect<T>({required BuildContext context, required List<DropdownMenuItem<T>> items, String searchHint = 'Search', bool? isMobile}) Future<T?>

Typedefs

FeeInfoChanged = void Function(FeeInfo? fee)
MetricData = ({AssetId? selectedAsset, double trendPercentage, double value})
Model representing metric data
SelectedItemBuilder<T> = Widget? Function(BuildContext context, T? selectedItem)
ValueChanged<T> = void Function(T value)
Signature for callbacks that report that an underlying value has changed.
VoidCallback = void Function()
Signature of callbacks that have no arguments and return no data.
WalletAddressEntry = ({String address, String balance, String label})
Represents a wallet address with its associated information.