protocolBorder property
The thickness of the border around the protocol icon.
If null, defaults to protocolSizeWithBorder * 0.1.
Implementation
final double? protocolBorder;
The thickness of the border around the protocol icon.
If null, defaults to protocolSizeWithBorder * 0.1.
final double? protocolBorder;