MetricSelectorController class

Controller for managing MetricSelector state

Inheritance

Constructors

MetricSelectorController({required MetricData data, required List<AssetId> availableAssets, bool allowEmptySelection = true})

Properties

allowEmptySelection bool
final
availableAssets List<AssetId>
final
data MetricData
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchController SearchableSelectController<AssetId>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
buildSelectItems({DropdownMenuItem<AssetId> customItemBuilder(AssetId)?}) List<DropdownMenuItem<AssetId>>
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
selectAsset(AssetId? asset) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited