SelectItem class

A model class representing a selectable item

Constructors

SelectItem({required String id, required String value, required Widget title, Widget? leading, Widget? trailing})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
leading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Widget
final
trailing Widget?
final
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited