AssetProtocolIcon class
A widget that displays a protocol icon with a circular border and shadow, positioned absolutely within its parent widget.
This widget is typically used to overlay a protocol icon on top of an asset logo to indicate the blockchain protocol or network the asset belongs to.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AssetProtocolIcon
Constructors
- AssetProtocolIcon({required String protocolTicker, required double logoSize, double? protocolSizeWithBorder, double? protocolBorder, double? protocolLeftPosition, double? protocolTopPosition, Key? key})
-
Creates an AssetProtocolIcon widget.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- logoSize → double
-
The size of the main logo that this protocol icon will be
positioned relative to.
final
- protocolBorder → double?
-
The thickness of the border around the protocol icon.
If null, defaults to
protocolSizeWithBorder * 0.1.final - protocolLeftPosition → double?
-
The left position offset for the protocol icon.
If null, defaults to
logoSize * 0.55.final - protocolSizeWithBorder → double?
-
The total size of the protocol icon including its border.
If null, defaults to
logoSize * 0.45.final - protocolTicker → String
-
The ticker symbol of the protocol to display as an icon.
final
- protocolTopPosition → double?
-
The top position offset for the protocol icon.
If null, defaults to
logoSize * 0.55.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited